@@ -5,7 +5,9 @@ use GRID::Machine::Group;
 use List::Util qw(sum);
 use Time::HiRes qw(time gettimeofday tv_interval);
 
-my @MACHINE_NAMES = split /\s+/, $ENV{MACHINES};
+my @MACHINE_NAMES = ('', '');
+@MACHINE_NAMES = split /\s+/, $ENV{MACHINES} if $ENV{MACHINES};
+
 my @m = map { GRID::Machine->new(host => $_, wait => 5, survive => 1) } @MACHINE_NAMES;
 
 my $c = GRID::Machine::Group->new(cluster => [ @m ]);
@@ -21,7 +23,7 @@ $c->sub(suma_areas => q{
    $sum /= $N; 
 });
 
-my ($N, $np, $pi)  = (1e7, 4, 0);
+my ($N, $np, $pi)  = (1e7, 32, 0);
 
 my @args = map {  [$_, $N, $np] } 0..$np-1;
 
