@@ -5,7 +5,8 @@ use Data::Dumper;
 use GRID::Machine;
 use GRID::Machine::Group;
 
-my @MACHINE_NAMES = split /\s+/, $ENV{MACHINES};
+my @MACHINE_NAMES = split /\s+/, ($ENV{MACHINES} || '');
+@MACHINE_NAMES = ('', '') unless @MACHINE_NAMES;
 my @m = map { GRID::Machine->new(host => $_) } @MACHINE_NAMES;
 
 my $group = GRID::Machine::Group->new(cluster => \@m);
